function count = CancerCells(change)
% CancerCells - Counts cancerous cells. Pass a string to reset.
%
% The function keeps a running count of the number of cancerous cells
% found. Pass it a string value (like 'reset') to reset the count to
% zero. When being reset, this function returns the string. Otherwise, 
% it returns the updated count.
%
% Preconditions: Count must be reset prior to incrementing or function
% will return an empty matrix.
%
% Postconditions: Count is saved from call to call and accumulates
% until reset.
%
% Created by C. S. Tritt, Ph.D.
% Last revised: 12/12/11 (Version 1.1)

   persistent state;
 
   if ischar(change)
      state = 0;
      count = change;
   else
      state = state + change;
      count = state;
   end
   return
end
